<div class="form-row">
    {% for widget in widget.subwidgets %}
        <div class="col-sm {% if not forloop.last %}mb-2 mb-sm-0{% endif %}">
            {% include widget.template_name %}
        </div>
    {% endfor %}
</div>
