{% load bootstrap4 %}

{% for error in form.non_field_errors %}
    <div class="alert alert-danger" role="alert">{{ error }}</div>
{% endfor %}

{% for field in form %}
    {% bootstrap_field field %}
{% endfor %}
