<input type="{{ widget.type }}" name="{{ widget.name }}" class="form-control" {% if widget.value != None %}value="{{ widget.value|stringformat:'s' }}"{% endif %}{% include "django/forms/widgets/attrs.html" %}>
